pub trait IterHttpHeaderFields<'a> {
type Fields: Iterator<Item = (&'a str, &'a [u8])>;
// Required method
fn fields(&'a self) -> Self::Fields;
}Expand description
This trait allows to iterate over the fields of a HTTP header.
pub trait IterHttpHeaderFields<'a> {
type Fields: Iterator<Item = (&'a str, &'a [u8])>;
// Required method
fn fields(&'a self) -> Self::Fields;
}This trait allows to iterate over the fields of a HTTP header.