SetHttpHeaderField

Trait SetHttpHeaderField 

pub trait SetHttpHeaderField {
    // Required method
    fn set_http_header_field(&mut self, name: &str, value: &str) -> Result<()>;
}
This trait allows to insert fields in a HTTP header.

Required Methods

fn set_http_header_field(&mut self, name: &str, value: &str) -> Result<()>

Sets the value of the field named name in the HTTP header to value.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<S: BuildHasher> SetHttpHeaderField for HashMap<String, String, S>

Source

fn set_http_header_field(&mut self, name: &str, value: &str) -> Result<()>

Implementors