pub struct StdLogFieldsBuilder<'a>(/* private fields */);Expand description
A specialized span log builder for the standard log fields.
Implementations
Sourceimpl StdLogFieldsBuilder<'_>
impl StdLogFieldsBuilder<'_>
Sourcepub fn event<T>(&mut self, event: T) -> &mut Self
pub fn event<T>(&mut self, event: T) -> &mut Self
Adds the field LogField::new("event", event).
event is a stable identifier for some notable moment in the lifetime of a Span.
For instance, a mutex lock acquisition or release or the sorts of lifetime events
in a browser page load described in the Performance.timing specification.
E.g., from Zipkin, "cs", "sr", "ss", or "cr".
Or, more generally, "initialized" or "timed out".