Module sampler

Module sampler 

Sampler trait and its built-in implementations.

Structs

AllSampler
This samples all traces.
AndSampler
and combinator.
NullSampler
This samples no traces.
OrSampler
or combinator.
PassiveSampler
This samples traces which have one or more references.
ProbabilisticSampler
This samples a certain percentage of traces.

Traits

Sampler
Sampler decides whether a new trace should be sampled or not.

Type Aliases

BoxSampler
Boxed version of Sampler.