BaggageItem

Struct BaggageItem 

pub struct BaggageItem { /* private fields */ }
Baggage item.

BaggageItems are key:value string pairs that apply to a Span, its SpanContext, and all Spans which directly or transitively reference the local Span. That is, BaggageItems propagate in-band along with the trace itself.

BaggageItems enable powerful functionality given a full-stack OpenTracing integration (for example, arbitrary application data from a mobile app can make it, transparently, all the way into the depths of a storage system), and with it some powerful costs: use this feature with care.

Use this feature thoughtfully and with care. Every key and value is copied into every local and remote child of the associated Span, and that can add up to a lot of network and cpu overhead.

Implementations

Source

impl BaggageItem

pub fn new(name: &str, value: &str) -> Self

Makes a new BaggageItem instance.

pub fn name(&self) -> &str

Returns the name of this item.

pub fn value(&self) -> &str

Returns the value of this item.