pub trait TextMap {
// Required methods
fn set(&mut self, key: &str, value: &str);
fn get(&self, key: &str) -> Option<&str>;
}Expand description
This trait represents carriers which support Text Map format.
Text Map is an arbitrary string-to-string map with an unrestricted character set for both keys and values.