pub struct BaggageItem { /* private fields */ }Expand description
Baggage item.
BaggageItems are key:value string pairs that apply to a Span, its SpanContext,
and all Spans which directly or transitively reference the local Span.
That is, BaggageItems propagate in-band along with the trace itself.
BaggageItems enable powerful functionality given a full-stack OpenTracing integration
(for example, arbitrary application data from a mobile app can make it, transparently,
all the way into the depths of a storage system),
and with it some powerful costs: use this feature with care.
Use this feature thoughtfully and with care.
Every key and value is copied into every local and remote child of the associated Span,
and that can add up to a lot of network and cpu overhead.
Implementations